PostgreSQL Backups
==================

Dumps
=====
...

File-based
==========

Setup
-----
1. Create the directory where the data will be stored.
```
mkdir -p /var/backups/postgresql/pg_log_archive
chown -R postgres:postgres /var/backups/postgresql/
```

2. Enable wal archiving and let postgresql copy the wal files for you:
/etc/postgresql/9.4/main/postgresql.conf:
```
# ALWAYS use either "hot_standby" or "archive". "minimal" won't be enough to restore data
wal_level = archive
# pg_basebackup uses the replication protocol to backup the data
max_wal_senders = 1
# minimum number of wal segments that will be stored (100 Files * 16MB)
# so you need 1.6 GB reserved for wal log
wal_keep_segments = 100
```

3. Give the `postgres` the permission to replicate the data
/etc/postgresql/9.4/main/pg_hba.conf:
```
# Allow replication connections from localhost, by a user with the
# replication privilege.
local   replication     postgres                                trust
```

4. Restart postgresql

```
systemctl restart postgresql
```
Restore
-------
1. Stop postgresql
```
systemctl stop postgresql
```

2. Move the current data and create directory structure again
```
mv /var/lib/postgresql /var/lib/postgresql2
mkdir -p /var/lib/postgresql/9.4/main
chown -R postgres:postgres /var/lib/postgresql/
chmod 700 /var/lib/postgresql/9.4/main
```

3. Untar the latest backup
```
tar xvf base.tar.gz -C /var/lib/postgresql/9.4/main
```

4. Create recovery conf
```
echo "restore_command = ''" > /var/lib/postgresql/9.4/main/restore.conf
```

5. Start postgresql and check the logfile
```
systemctl start postgresql
tail -f /var/log/postgresql/postgresql-9.4-main.log
```
